@@ -12,12 +12,14 @@ __all__ = ('ModelInlineBase', 'ModelInline', 'ModelTemplateInline',)
 
 
 class ModelInlineOptions(InlineOptions):
+
     def __init__(self, meta, args, app_label):
         self.model = getattr(meta, 'model', None)
         super(ModelInlineOptions, self).__init__(meta, args, app_label)
 
 
 class ModelInlineMetaClass(InlineMetaClass):
+
     def get_inline_options(cls, base_meta, meta, args, app_label=None):
         opts = ModelInlineOptions(meta, args, app_label)
         cls.carryover_options(base_meta, opts)
@@ -32,6 +34,7 @@ class ModelInlineMetaClass(InlineMetaClass):
 
 
 class ModelInlineBase(InlineBase):
+
     def __init__(self, name, variant=None, *args, **kwargs):
         self.object = None
 
@@ -69,14 +72,15 @@ class ModelInlineBase(InlineBase):
 
 
 class ModelTemplateInlineBase(TemplateInlineMixin, ModelInlineBase):
+
     def get_context(self):
         return {'object': self.object}
 
 
-class ModelInline(ModelInlineBase, six.with_metaclass(ModelInlineMetaClass)):
+class ModelInline(six.with_metaclass(ModelInlineMetaClass, ModelInlineBase)):
     pass
 
 
-class ModelTemplateInline(ModelTemplateInlineBase,
-                          six.with_metaclass(ModelInlineMetaClass)):
+class ModelTemplateInline(
+        six.with_metaclass(ModelInlineMetaClass, ModelTemplateInlineBase)):
     pass
